@@ -54,7 +54,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -133,42 +133,42 @@ sub configure {
     $self->add_plugins(
 
         [ 'Hook' => 'prologue' => { # DOES NOT WORK.
-            'hook' => [
-                q| use autodie ':all';                     |,
-                q| use IPC::System::Simple qw{ capture };  |,
-                q| use Path::Tiny;                         |,
-            ],
+            'hook' => [ q{
+                use autodie ':all';
+                use IPC::System::Simple qw{ capture };
+                use Path::Tiny;
+            } ],
         } ],
 
         [ 'Hook::VersionProvider' => {
-            'hook' => [
-                q| use Path::Tiny;                          |,
-                q| path( 'VERSION' )->slurp =~ s{\s+\z}{}r; |,
-            ],
+            'hook' => [ q{
+                use Path::Tiny;
+                path( 'VERSION' )->slurp =~ s{\s+\z}{}r;
+            } ],
         } ],
 
         [ 'Hook::Init' => 'my vars' => {
-            'hook' => [
-                q|  package MY {                                                                              |,
-                q|      our $name           = $dist->name;                                                    |,
-                q|      our $package        = $name =~ s{-}{::}gr;                                            |,
-                q|      our $version        = $dist->version;                                                 |,
-                q|      our $Abstract       = $dist->abstract;                                                |,
-                q|      our $abstract       = lcfirst( $Abstract );                                           |,
-                q|      our $author         = $dist->authors->[ -1 ];                                         |,
-                q|      our $metacpan       = "https://metacpan.org/release/$name";                           |,
-                q|      our $cpan_rt_mailto = "mailto:bug-$name\@rt.cpan.org";                                |,
-                q|      our $cpan_rt_browse = "https://rt.cpan.org/Public/Dist/Display.html?Name=$name";      |,
-                q|      our $cpan_rt_report = "https://rt.cpan.org/Public/Bug/Report.html?Queue=$name";       |,
-                q|      our $repo_type      = "hg";                                                           |,
-                q|      our $repo_host      = "fedorapeople.org";                                             |,
-                q|      our $repo_url       = "https://vandebugger.$repo_host/hg/perl-$name";                 |,
-                q|      our $repo_web       = undef;                                                          |,
-                q|      our $repo_clone     = "$repo_type clone $repo_url" .                                  |,
-                q|          ( $repo_url =~ m{/\Qperl-$name\E\z} ? '' : " \\\n        perl-$name" );           |,
-                q|  };                                                                                        |,
-                q| $ENV{ 'TEST_FIX' . 'ME_FORMAT' } = 'perl';                                                 |,
-            ],
+            'hook' => [ q{
+                pack} . q{age MY {          # Hide declaration from `new-version.t`.
+                    our $name           = $dist->name;
+                    our $package        = $name =~ s{-}{::}gr;
+                    our $version        = $dist->version;
+                    our $Abstract       = $dist->abstract;
+                    our $abstract       = lcfirst( $Abstract );
+                    our $author         = $dist->authors->[ -1 ];
+                    our $metacpan       = "https://metacpan.org/release/$name";
+                    our $cpan_rt_mailto = "mailto:bug-$name\@rt.cpan.org";
+                    our $cpan_rt_browse = "https://rt.cpan.org/Public/Dist/Display.html?Name=$name";
+                    our $cpan_rt_report = "https://rt.cpan.org/Public/Bug/Report.html?Queue=$name";
+                    our $repo_type      = "hg";
+                    our $repo_host      = "fedorapeople.org";
+                    our $repo_url       = "https://vandebugger.$repo_host/hg/perl-$name";
+                    our $repo_web       = undef;
+                    our $repo_clone     = "$repo_type clone $repo_url" .
+                        ( $repo_url =~ m{/\Qperl-$name\E\z} ? '' : " \\\n        perl-$name" );
+                };
+                $ENV{ 'TEST_FIX' . 'ME_FORMAT' } = 'perl';      # Hide keyword from `fixme.t`.
+            } ],
         } ],
 
         #
@@ -193,33 +193,48 @@ sub configure {
         #
 
         [ 'OurPkgVersion' ],
+
         [ 'SurgicalPodWeaver' => {
             'replacer'      => 'replace_with_comment',
             'config_plugin' => '@Author::VDB',
         } ],
 
+        [ 'FileFinder::ByName' => 'doc' => {
+            # Plugin name will be `@Author::VDB/doc`.
+            'file' => [
+                'COPYING',
+                'README',
+            ],
+        } ],
+
+        [ 'Templates' => {
+            'templates' => [
+                '@Author::VDB/doc',
+            ],
+        } ],
+
         #
         #   Update sources
         #
 
+        #   Copy built doc files back to source directory.
         [ 'Hook::AfterBuild' => {
-            'hook' => [
-                q| #   Copy built files back to source directory.          |,
-                q| use Path::Tiny;                                         |,
-                q| my @files = qw{ COPYING README };   # Files to copy.    |,
-                q| my $build = path( $arg->{ build_root } );               |,
-                q| my $root  = path( $dist->root );                        |,
-                q| for my $file ( @files ) {                               |,
-                q|     my $nfile = $build->child( $file );                 |,
-                q|     my $ofile = $root->child( $file );                  |,
-                q|     my $new = $nfile->slurp;                            |,
-                q|     my $old = $ofile->exists ? $ofile->slurp : undef;   |,
-                q|     if ( not defined( $old ) or $new ne $old ) {        |,
-                q|         $self->log( [ 'Updating %s...', $file ] );      |,
-                q|         $ofile->spew( $new );                           |,
-                q|     };                                                  |,
-                q| };                                                      |,
-            ],
+            'hook' => [ q{
+                use Path::Tiny;
+                my $files = $zilla->plugin_named( '@Author::VDB/doc' )->find_files();
+                my $build = path( $arg->{ build_root } );
+                my $root  = path( $dist->root );
+                for my $file ( @$files ) {
+                    my $new_file = $build->child( $file->name );
+                    my $old_file = $root->child( $file->name );
+                    my $new_bulk = $new_file->slurp;
+                    my $old_bulk = $old_file->exists ? $old_file->slurp : undef;
+                    if ( not defined( $old_bulk ) or $new_bulk ne $old_bulk ) {
+                        $self->log( [ 'Updating %s...', $file->name ] );
+                        $old_file->spew( $new_bulk );
+                    };
+                };
+            } ],
         } ],
 
         #
@@ -298,26 +313,66 @@ sub configure {
 
         [ 'AutoPrereqs' ],
 
-        [ 'Prereqs::AuthorDeps' ],
+        #   `Prereqs::AuthorDeps` has a problem:
+        #       <https://github.com/dagolden/Dist-Zilla-Plugin-Prereqs-AuthorDeps/issues/1>
+        #   It adds local plugins (e. g. tools::GenerateHooks) to the dependencies,
+        #   which obviously are not indexed on CPAN.
+        [ 'Prereqs::AuthorDeps' => {
+            #~ 'exclude' => [
+                #~ #   Exclude option requires a list of specific files, while I want to ignore all
+                #~ #   files in specific directory.
+            #~ ],
+        } ],
 
-        [ 'Hook::PrereqSource' => {
-            'hook' => [
-                #   `use autodie ':all';` implicitly requires `IPC::System::Simple` module, but
-                #    this dependency is not detected by `AutoPrereqs`. If there is dependency on
-                #   `autodie`, let us add dependency on `IPC::System::Simple`.
-                q| my $prereqs = $dist->prereqs->as_string_hash;                              |,
-                q| for my $phase ( keys( %$prereqs ) ) {                                      |,
-                q|     for my $type ( keys( %{ $prereqs->{ $phase } } ) ) {                   |,
-                q|         if ( exists( $prereqs->{ $phase }->{ $type }->{ autodie } ) ) {    |,
-                q|             $self->log_debug( [ 'phase %s type %s', $phase, $type ] );     |,
-                q|             $zilla->register_prereqs(                                      |,
-                q|                 { phase => $phase, type => $type },                        |,
-                q|                 'IPC::System::Simple' => 0,                                |,
-                q|             );                                                             |,
-                q|         };                                                                 |,
-                q|     };                                                                     |,
-                q| };                                                                         |,
-            ],
+        #   TODO: Remove when possible.
+        #   This is a dirty hack. Remove it when `Prereqs::AuthorDeps` allows me to ignore all the
+        #   modules from `tools/` directory. Meanwhile, find and remove all the dependencies on
+        #   modules with `tools::` prefix.
+        [ 'Hook::PrereqSource' => 'tools' => {
+            'hook' => [ q{
+                my $prereqs = $dist->prereqs->cpan_meta_prereqs;
+                for my $phase ( $prereqs->__legal_phases ) {
+                for my $type  ( $prereqs->__legal_types  ) {
+                    my $reqs = $prereqs->requirements_for( $phase, $type ) or next;
+                    for my $module ( keys( %{ $reqs->{ requirements } } ) ) {
+                        if ( $module =~ m{^tools::} ) {
+                            $self->log_debug( [
+                                'found dependency on module %s at phase %s of type %s, deleting it',
+                                $module, $phase, $type
+                            ] );
+                            delete( $reqs->{ requirements }->{ $module } );
+                        };
+                    };
+                };
+                };
+            } ],
+        } ],
+
+        #   `use autodie ':all';` implicitly requires `IPC::System::Simple` module, but this
+        #   dependency is not detected by `AutoPrereqs`. If there is dependency on `autodie`, let
+        #   us add dependency on `IPC::System::Simple`.
+        [ 'Hook::PrereqSource' => 'autodie' => {
+            'hook' => [ q{
+                my $prereqs = $dist->prereqs->cpan_meta_prereqs;
+                for my $phase ( $prereqs->__legal_phases ) {
+                for my $type  ( $prereqs->__legal_types  ) {
+                    my $reqs = $prereqs->requirements_for( $phase, $type ) or next;
+                    for my $module ( keys( %{ $reqs->{ requirements } } ) ) {
+                        if ( $module eq 'autodie' ) {
+                            $self->log_debug( [
+                                'found dependency on module %s at phase %s type %s, ' .
+                                    'adding dependency on IPC::System::Simple',
+                                $module, $phase, $type
+                            ] );
+                            $dist->register_prereqs(
+                                { phase => $phase, type => $type },
+                                'IPC::System::Simple' => 0,
+                            );
+                        };
+                    };
+                };
+                };
+            } ],
         } ],
 
         [ 'CheckPrereqsIndexed'   ],    # Make sure all prereqs are published in CPAN.
@@ -356,46 +411,46 @@ sub configure {
 
         [ 'TestRelease'     ],          # Unpack tarball and run tests.
 
-        [ 'Hook::BeforeRelease' => 'check prereqs' => {
-            'hook' => [
-                q| #   Make sure the distro does not depend on unwanted modules.                    |,
-                q| #   Unwanted module, for example, is `Data::Printer`.                            |,
-                q| #   I use it often for debugging purposes and forget to remove debugging code.   |,
-                q| my @modules = qw{ DDP Data::Printer };                                           |, # TODO: Parameter
-                q| my $prereqs = $dist->distmeta->{ prereqs };                                      |,
-                q| for my $module ( @modules ) {                                                    |,
-                q|     for my $stage ( qw{ configure develop runtime test } ) {                     |,
-                q|         if ( exists( $prereqs->{ $stage }->{ requires }->{ $module } ) ) {       |,
-                q|             $self->log_error( [ '%s found in %s prereqs ', $module, $stage ] );  |,
-                q|         };                                                                       |,
-                q|     };                                                                           |,
-                q| };                                                                               |,
-                q| $self->abort_if_error();                                                         |,
-            ]
+        #   Make sure the distro does not depend on unwanted modules. Unwanted module, for example,
+        #   is `Data::Printer`. I use it often for debugging purposes and forget to remove
+        #   debugging code.
+        [ 'Hook::BeforeRelease' => 'unwanted deps' => {
+            'hook' => [ q{
+                my @modules = qw{ DDP Data::Printer };          # TODO: Parameter
+                my $prereqs = $dist->distmeta->{ prereqs };
+                for my $module ( @modules ) {
+                    for my $stage ( qw{ configure develop runtime test } ) {
+                        if ( exists( $prereqs->{ $stage }->{ requires }->{ $module } ) ) {
+                            $self->log_error( [ '%s found in %s prereqs ', $module, $stage ] );
+                        };
+                    };
+                };
+                $self->abort_if_error();
+            } ]
         } ],
 
         [ 'Hook::BeforeRelease' => 'hg stat' => {
-            'hook' => [
-                q| #   Make sure all the files committed.           |,
-                q| use IPC::System::Simple 'capture';               |,
-                q| my @stdout = capture( 'hg', 'status' );          |,
-                q| if ( @stdout ) {                                 |,
-                q|     chomp( @stdout );                            |,
-                q|     $self->log_error( 'hg status:' );            |,
-                q|     $self->log_error( "    $_" ) for @stdout;    |,
-                q|     $self->abort( 'hg status is not clean' );    |,
-                q| };                                               |,
-            ],
+            'hook' => [ q{
+                #   Make sure all the files committed.
+                use IPC::System::Simple 'capture';
+                my @stdout = capture( 'hg', 'status' );
+                if ( @stdout ) {
+                    chomp( @stdout );
+                    $self->log_error( 'hg status:' );
+                    $self->log_error( "    $_" ) for @stdout;
+                    $self->abort( 'hg status is not clean' );
+                };
+            } ],
         } ],
 
-        [ 'Hook::BeforeRelease' => 'hg tag' => {
-            'hook' => [
-                q| #   Make sure there is no such tag yet.                          |,
-                q| use Path::Tiny;                                                  |,
-                q| if ( path( '.hgtags' )->slurp_utf8 =~ m{ \Q$MY::version\E$}m ) { |,
-                q|     $self->abort( [ 'tag %s already exists', $MY::version ] );   |,
-                q| };                                                               |,
-            ],
+        [ 'Hook::BeforeRelease' => 'hg check tag' => {
+            'hook' => [ q{
+                #   Make sure there is no such tag yet.
+                use Path::Tiny;
+                if ( path( '.hgtags' )->slurp_utf8 =~ m{ \Q$MY::version\E$}m ) {
+                    $self->abort( [ 'tag %s already exists', $MY::version ] );
+                };
+            } ],
         } ],
 
         [ 'ConfirmRelease' ],       # Ask confirmation before uploading the release.
@@ -403,21 +458,21 @@ sub configure {
         [ $self->fake_release ? 'FakeRelease' : 'UploadToCPAN' ],
 
         [ 'Hook::AfterRelease' => 'hg add tag' => {
-            'hook' => [
-                q| use IPC::System::Simple 'capture';                                    |,
-                q| my @stdout = capture( 'hg', 'id', '--debug' );                        |,
-                q| chomp( @stdout );                                                     |,
-                q| @stdout == 1 and $stdout[ 0 ] =~ m{^([0-9a-f]{40})(\+?) tip$} or do { |,
-                q|     $self->log_error( 'fail to parse "hg id" output:' );              |,
-                q|     $self->log_error( "    $_" ) for @stdout;                         |,
-                q|     $self->abort();                                                   |,
-                q| };                                                                    |,
-                q| my ( $id, $dirty ) = ( $1, $2 );                                      |,
-                q| if ( $dirty ) {                                                       |,
-                q|     $self->abort( 'hg status is not clean' );                         |,
-                q| };                                                                    |,
-                q| path( '.hgtags' )->append( "$id $MY::version\n" );                    |,
-            ],
+            'hook' => [ q{
+                use IPC::System::Simple 'capture';
+                my @stdout = capture( 'hg', 'id', '--debug' );
+                chomp( @stdout );
+                @stdout == 1 and $stdout[ 0 ] =~ m{^([0-9a-f]{40})(\+?) tip$} or do {
+                    $self->log_error( 'fail to parse "hg id" output:' );
+                    $self->log_error( "    $_" ) for @stdout;
+                    $self->abort();
+                };
+                my ( $id, $dirty ) = ( $1, $2 );
+                if ( $dirty ) {
+                    $self->abort( 'hg status is not clean' );
+                };
+                path( '.hgtags' )->append( "$id $MY::version\n" );
+            } ],
         } ],
 
         $self->fake_release ? (
@@ -433,40 +488,43 @@ sub configure {
         } ],
 
         [ 'Hook::AfterRelease' => 'bump version' => {
-            'hook' => [
-                q| use Path::Tiny;                                        |,
-                q| use Perl::Version;                                     |,
-                q| my $version = Perl::Version->new( $dist->version );    |,
-                q| $version->inc_alpha;                                   |,
-                q| path( 'VERSION' )->spew( $version );                   |,
-                q| $self->log( [ 'Next release will be %s', $version ] ); |,
-            ],
+            'hook' => [ q{
+                use Path::Tiny;
+                use Perl::Version;
+                my $version = Perl::Version->new( $dist->version );
+                $version->inc_alpha;
+                path( 'VERSION' )->spew( $version );
+                $self->log( [ 'Next release will be %s', "$version" ] );
+            } ],
         } ],
 
-        [ 'Hook::AfterRelease' => 'hg post commit' => {
-            'hook' => [
-                q| use autodie ':all';                                                                     |,
-                q| system( 'hg', 'commit', '-m', 'Post-release commit', '.hgtags', 'VERSION', 'Changes' ); |,
-            ],
+        [ 'Hook::AfterRelease' => 'hg post-commit' => {
+            'hook' => [ q{
+                use autodie ':all';
+                system(
+                    'hg', 'commit', '-m', 'Post-release commit',
+                        qw{ .hgtags VERSION Changes }
+                );
+            } ],
         } ],
 
         [ 'Hook::AfterRelease' => 'hg push' => {
             'hook' => [
-                $self->fake_release ? (
-                    q| $self->log( 'Fake release, skipping "hg push"...' ); |,
-                ) : (
-                    q| use IPC::System::Simple 'capture';    |,
-                    q| my @stdout = capture( 'hg', 'push' ); |,
-                    q| chomp( @stdout );                     |,
-                    q| $self->log( "    $_" ) for @stdout;   |,
-                ),
+                $self->fake_release ? ( q{
+                    $self->log( 'Fake release, skipping "hg push"...' );
+                } ) : ( q{
+                    use IPC::System::Simple 'capture';
+                    my @stdout = capture( 'hg', 'push' );
+                    chomp( @stdout );
+                    $self->log( "    $_" ) for @stdout;
+                } ),
             ],
         } ],
 
         [ 'Hook::AfterRelease' => 'clean' => {
-            'hook' => [
-                q| $zilla->clean(); |,
-            ],
+            'hook' => [ q{
+                $zilla->clean();
+            } ],
         } ],
 
     );
@@ -519,7 +577,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.004, released on 2015-08-09 22:12 UTC.
+Version 0.005, released on 2015-08-11 20:08 UTC.
 
 =head1 WHAT?
 
